#ifndef _FOO_VIEWS_H_FOO_
#define _FOO_VIEWS_H_FOO_

#include <hildon/hildon.h>

#include "userdata.h"
#include "glue.h"

/* stored playlists */
void yaspot_show_stored_playlists(userdata_t *u);
/* window parameter -> which window is set "loading", may be NULL */
void yaspot_show_stored_list_by_id(userdata_t *u, const gchar *id, GtkWidget *window);

void yaspot_show_search(userdata_t *u, const gchar *search);

void yaspot_show_artist(userdata_t *u, yaspot_glue_response_t *list, gint num, GtkWidget *window);
void yaspot_show_album(userdata_t *u, yaspot_glue_response_t *list, gint num, GtkWidget *window);
void yaspot_show_album_by_id(userdata_t *u, const gchar *id, GtkWidget *window);
void yaspot_show_biography(userdata_t *u, yaspot_glue_response_t *r);

void yaspot_show_queue(userdata_t *u);

#endif

